#
# spec file for package python-Brotli
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Brotli
Version:        1.1.0
Release:        1.1
Summary:        Python bindings for the Brotli compression library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://pypi.org/project/Brotli/
Source:         https://files.pythonhosted.org/packages/source/B/Brotli/Brotli-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Brotli is a generic-purpose lossless compression algorithm that compresses data
using a combination of a modern variant of the LZ77 algorithm, Huffman coding
and 2nd order context modeling, with a compression ratio comparable to the best
currently available general-purpose compression methods. It is similar in speed
with deflate but offers more dense compression.

The specification of the Brotli Compressed Data Format is defined in RFC 7932.

%prep
%setup -q -n Brotli-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/*

%changelog
* Mon Sep 11 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * added CLI --dictionary option
  * decoder: faster decoding
  * encoder: faster encoding
  * encoder: smaller stack frames
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Jan 22 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.9 (CVE-2020-8927, bsc##1175825):
  * Fix integer overflow when input chunk is longer than
    2GiB
  * `brotli -v` now reports raw / compressed size
  * decoder: minor speed / memory usage improvements
  * encoder: fix rare access to uninitialized data in ring-buffer
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.7:
  * aarch64 speedups
  * minor fixes
  * java 8->9 compatibility
* Thu May 24 2018 toddrme2178@gmail.com
- Update to version 1.0.4
  * fix unaligned access for aarch64-cross-armhf build
  * fix aarch64 target detection
  * allow CLI to compress with enabled "large window" feature
  * add NPOSTFIX / NDIRECT encoder parameters
  * automatic NDIRECT/NPOSTFIX tuning (better compression)
  * fix "memory leak" in python tests
  * fix bug in durchschlag
  * fix source file lists (add params.h)
  * fix Bazel/MSVC compilator options
  * fix "fall though" warnings
- Update to version 1.0.3
  + Key changes:
  * new feature: "Large Window Brotli"
  * new dictionary generator
  + Other changes:
  * improved compression ratio: sub-blocks stitching
  * improved compression ratio: eliminated floating numbers rounding
  * improved compression ratio: make the zopflification aware of NDIRECT, NPOSTFIX
  * improve automake build
  * improve BrotliEncoderMaxCompressedSize precision
  * fix API documentation / typos
  * fix code style
  * make hashers host-endianness-independent
  * Java: added "eager" decoding both to JNI wrapper and pure decoder
  * CLI: window size is auto-adjusted
  * added dictionaryless compressed dictionary
- Update to version 1.0.2
  + Major changes:
  * added Autotools build files
  * switched shared library version to libtool scheme
  + Minor changes:
  * BrotliDictionary members are not const now
  * ZopfliNode distance could be up to 128MiB
  * fixed API documentation typos
  * total_out is always set by decoder
  * fixed BROTLI_ENSURE_CAPACITY macro; no-op in preprocessed output
  + Other changes:
  * fixed scripts for oss-fuzz, test them with Travis
  * made Bazel JNI tests less messy
  * fixed linter warnings in JS decoder
  * fixed permissions of various files
  * added Bazel build to Appveyor matrix
  * added Sieve dictionary generator
- Update to version 1.0.1
  * updated README.md
  * fixed parallel exeuction of CMake "compatibility" tests
- Update to version 1.0.0
  + API changes
  * new CLI; bro -> brotli; + man page
  * remove "custom dictionary" support
  * add ability to side-load brotli RFC dictionary
  * add decoder API to avoid ringbuffer reallocation
  * PY streaming decompression support
  * PY wrapper accepts memview
  + New features
  * C# decoder (transpiled from Java)
  * JS decoder (transpiled from Java)
  * JNI wrappers
  + Improvements
  * speedup Java decoder
  * speedup compression of RLE-ish data
- Spec file cleanups
* Thu May 25 2017 toddrme2178@gmail.com
- Initial version
